@@ -413,6 +413,9 @@ void file_cleanup(struct group_list_t *group, int abort_session)
                 }
             }
         }
+        if (!abort_session && !strcmp(tempdir, "")) {
+            run_postreceive(group, group->fileinfo.filepath);
+        }
     }
 
     if (abort_session || (group->file_id == 0)) {
@@ -468,9 +471,6 @@ void file_cleanup(struct group_list_t *group, int abort_session)
         memset(group, 0, sizeof(struct group_list_t));
     } else {
         // Don't clear the file_id in case we need to respond to late DONEs
-        if (!strcmp(tempdir, "")) {
-            run_postreceive(group, group->fileinfo.filepath);
-        }
         group->phase = PHASE_MIDGROUP;
         set_timeout(group, 0);
         free(group->fileinfo.naklist);
@@ -1048,7 +1048,12 @@ void new_loss_event(struct group_list_t *group, uint16_t txseq)
         }
         rate = (int)(bytes / group->grtt);
         glog4(group, "End slowstart, calculated rate = %d", rate);
-        avgbytes = bytes / (group->max_txseq - count);
+        if ((group->max_txseq == count) || (bytes == 0)) {
+            glog4(group, "using datapacketsize as avgsize");
+            avgbytes = group->datapacketsize;
+        } else {
+            avgbytes = bytes / (group->max_txseq - count);
+        }
         group->loss_events[0].len = (int)(0 + pow(
                 (rate * ((group->rtt != 0) ? group->rtt : group->grtt)) / 
                 (sqrt(1.5) * 8 * avgbytes), 2));
