@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -415,9 +415,15 @@ void create_sockets(void)
             int mtuflag = IP_PMTUDISC_DONT;
             if (setsockopt(listener, IPPROTO_IPV6, IPV6_MTU_DISCOVER,
                            (char *)&mtuflag, sizeof(mtuflag)) == SOCKET_ERROR) {
+#ifdef WINDOWS
+              if (WSAGetLastError() != WSAENOPROTOOPT) {
+#endif
                 sockerror(0, 0, 0, "Error disabling MTU discovery");
                 closesocket(listener);
                 exit(ERR_SOCKET);
+#ifdef WINDOWS
+              }
+#endif
             }
         }
 #endif
@@ -456,9 +462,15 @@ void create_sockets(void)
             int mtuflag = IP_PMTUDISC_DONT;
             if (setsockopt(listener, IPPROTO_IP, IP_MTU_DISCOVER,
                     (char *)&mtuflag, sizeof(mtuflag)) == SOCKET_ERROR) {
+#ifdef WINDOWS
+              if (WSAGetLastError() != WSAENOPROTOOPT) {
+#endif
                 sockerror(0, 0, 0, "Error disabling MTU discovery");
                 closesocket(listener);
                 exit(ERR_SOCKET);
+#ifdef WINDOWS
+              }
+#endif
             }
         }
 #endif
@@ -584,13 +596,16 @@ void initialize(void)
         freeaddrinfo(ai_rval);
     }
     if (!uid) {
-        if (m_interface[0].su.ss.ss_family == AF_INET6) {
-            uid = m_interface[0].su.sin6.sin6_addr.s6_addr[12] << 24;
-            uid |= m_interface[0].su.sin6.sin6_addr.s6_addr[13] << 16;
-            uid |= m_interface[0].su.sin6.sin6_addr.s6_addr[14] << 8;
-            uid |= m_interface[0].su.sin6.sin6_addr.s6_addr[15];
-        } else {
-            uid = m_interface[0].su.sin.sin_addr.s_addr;
+        for (i = 0; i < interface_count; i++) {
+            if (m_interface[i].su.ss.ss_family == AF_INET6) {
+                uid = m_interface[i].su.sin6.sin6_addr.s6_addr[12] << 24;
+                uid |= m_interface[i].su.sin6.sin6_addr.s6_addr[13] << 16;
+                uid |= m_interface[i].su.sin6.sin6_addr.s6_addr[14] << 8;
+                uid |= m_interface[i].su.sin6.sin6_addr.s6_addr[15];
+            } else {
+                uid = m_interface[i].su.sin.sin_addr.s_addr;
+            }
+            if (uid) break;
         }
     }
 
