@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2016   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -280,23 +280,23 @@ void read_restart_file(const char *restart_name)
  */
 static int get_keytype(const char *name)
 {
-    if (!strcmp(optarg, "none")) {
+    if (!strcmp(name, "none")) {
         return KEY_NONE;
-    } else if (!strcmp(optarg, "des")) {
+    } else if (!strcmp(name, "des")) {
         return KEY_DES;
-    } else if (!strcmp(optarg, "3des")) {
+    } else if (!strcmp(name, "3des")) {
         return KEY_DES_EDE3;
-    } else if (!strcmp(optarg, "aes128-cbc")) {
+    } else if (!strcmp(name, "aes128-cbc")) {
         return KEY_AES128_CBC;
-    } else if (!strcmp(optarg, "aes256-cbc")) {
+    } else if (!strcmp(name, "aes256-cbc")) {
         return KEY_AES256_CBC;
-    } else if (!strcmp(optarg, "aes128-gcm")) {
+    } else if (!strcmp(name, "aes128-gcm")) {
         return KEY_AES128_GCM;
-    } else if (!strcmp(optarg, "aes256-gcm")) {
+    } else if (!strcmp(name, "aes256-gcm")) {
         return KEY_AES256_GCM;
-    } else if (!strcmp(optarg, "aes128-ccm")) {
+    } else if (!strcmp(name, "aes128-ccm")) {
         return KEY_AES128_CCM;
-    } else if (!strcmp(optarg, "aes256-ccm")) {
+    } else if (!strcmp(name, "aes256-ccm")) {
         return KEY_AES256_CCM;
     } else {
         return -1;
@@ -309,13 +309,13 @@ static int get_keytype(const char *name)
  */
 static int get_hashtype(const char *name)
 {
-    if (!strcmp(optarg, "sha1")) {
+    if (!strcmp(name, "sha1")) {
         return HASH_SHA1;
-    } else if (!strcmp(optarg, "sha256")) {
+    } else if (!strcmp(name, "sha256")) {
         return HASH_SHA256;
-    } else if (!strcmp(optarg, "sha384")) {
+    } else if (!strcmp(name, "sha384")) {
         return HASH_SHA384;
-    } else if (!strcmp(optarg, "sha512")) {
+    } else if (!strcmp(name, "sha512")) {
         return HASH_SHA512;
     } else {
         return -1;
