@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -330,9 +330,15 @@ void create_sockets(void)
             int mtuflag = IP_PMTUDISC_DONT;
             if (setsockopt(sock, IPPROTO_IPV6, IPV6_MTU_DISCOVER,
                            (char *)&mtuflag, sizeof(mtuflag)) == SOCKET_ERROR) {
+#ifdef WINDOWS
+              if (WSAGetLastError() != WSAENOPROTOOPT) {
+#endif
                 sockerror(0, 0, 0, "Error disabling MTU discovery");
                 closesocket(sock);
                 exit(ERR_SOCKET);
+#ifdef WINDOWS
+              }
+#endif
             }
         }
 #endif
@@ -363,9 +369,15 @@ void create_sockets(void)
             int mtuflag = IP_PMTUDISC_DONT;
             if (setsockopt(sock, IPPROTO_IP, IP_MTU_DISCOVER, (char *)&mtuflag, 
                            sizeof(mtuflag)) == SOCKET_ERROR) {
+#ifdef WINDOWS
+              if (WSAGetLastError() != WSAENOPROTOOPT) {
+#endif
                 sockerror(0, 0, 0, "Error disabling MTU discovery");
                 closesocket(sock);
                 exit(ERR_SOCKET);
+#ifdef WINDOWS
+              }
+#endif
             }
         }
 #endif
@@ -447,7 +459,7 @@ void key_init(void)
     // Sets the first 4 bytes of rand1 to the current time
     t = time(NULL);
     t2 = (uint32_t)(t & 0xFFFFFFFF);
-    *(uint32_t *)rand1 = t2;
+    memcpy(&rand1, &t2, sizeof(t2));
 
     explen = hmaclen + keylen + SALT_LEN;
     prf_buf = safe_calloc(explen + hmaclen, 1);
