@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -915,7 +915,7 @@ void transfer_receive_thread(struct finfo_t *finfo)
             rate /= 2;
             if ((min_rate > 0) && (rate < min_rate)) {
                 slowstart = 1;
-                if (min_rate < (int)(datapacketsize / grtt)) {
+                if (min_rate > (int)(datapacketsize / grtt)) {
                     rate = min_rate;
                 } else {
                     rate = (int)(datapacketsize / grtt);
@@ -954,7 +954,7 @@ void transfer_receive_thread(struct finfo_t *finfo)
             glog5(finfo, "adv_grtt=%.3f", l_adv_grtt);
             if ((min_rate > 0) && (rate < min_rate)) {
                 slowstart = 1;
-                if (min_rate < (int)(datapacketsize / grtt)) {
+                if (min_rate > (int)(datapacketsize / grtt)) {
                     rate = min_rate;
                 } else {
                     rate = (int)(datapacketsize / grtt);
