@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -395,6 +395,14 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
             rate = max_rate;
             slowstart = 0;
         }
+        if ((min_rate > 0) && (rate < min_rate)) {
+            slowstart = 1;
+            rate = min_rate;
+        }
+        if (rate < (int)(datapacketsize / grtt)) {
+            slowstart = 1;
+            rate = (int)(datapacketsize / grtt);
+        }
         packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
         last_clr_time = now;
     } else {
@@ -414,6 +422,14 @@ void handle_tfmcc_ack_info(const struct finfo_t *finfo,
                     rate = max_rate;
                     slowstart = 0;
                 }
+                if ((min_rate > 0) && (rate < min_rate)) {
+                    slowstart = 1;
+                    rate = min_rate;
+                }
+                if (rate < (int)(datapacketsize / grtt)) {
+                    slowstart = 1;
+                    rate = (int)(datapacketsize / grtt);
+                }
                 packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
                 rate_change = 1;
             } else if (client_rate < (unsigned)rate) {
